# ifcbUTOPIA Data Pipeline Tools

This repository contains a collection of tools to streamline the process of converting raw IFCB data to CNN-labeled and validated datasets. These dictionaries, functions, and classes are contained in the `utopia_pipeline_tools` folder.

Currently, the toolkit is under construction, but it is registered with PyPi [here](https://pypi.org/project/utopia-pipeline-tools/) and can be installed to a local machine using pip: `pip install utopia-pipeline-tools`.  

Load the package into a Python file with `import utopia_pipeline_tools as upt`. More package and module information is on the utopia-pipeline-tools section of the ifcbUTOPIA [website](https://ifcb-utopia.github.io/repositories/utopia-pipeline-tools/).

